from pript import pript


def draw_receipt():
  pript(sep='*')
  pript('HalfBakedCoffee Company', pos='center')
  pript('014210 Half Baked Ave.', pos='center')
  pript(' Receipt ', pos='center', sep="*")
  pript('Date: ', ' 04/02/2023 11:54:02')
  pript()
  pript(' Item list ', pos='center', sep="*")
  pript('Item: ', ' Big Coffee')
  pript('Quantity: ', ' 2')
  pript('Price: ', ' $5.00', sep='.')
  pript()
  pript(sep="*")
  pript('Item: ', ' Small Coffee')
  pript('Quantity: ', ' 2')
  pript('Price: ', ' $2.50', sep='.')
  pript()
  pript(sep="*")
  pript('Total: ', ' $15.00', sep='.')
  pript('Paid: ', ' $15.00', sep='.')
  pript('Thank you! ', ' Mr. Buyer')
  pript(sep='*')


if __name__ == '__main__':
    draw_receipt()



from pript import pript


def draw_flag():
    pript(sep='~')
    for i in range(6):
        if i % 2 == 0:
            pript(' *  ' * 6, '-' * 20)
        else:
            pript('   *' * 4, '~' * 20)
    pript(sep='-')
    for i in range(4):
        if i % 2 == 0:
            pript(sep='~')
        else:
            pript(sep='-')
    pript(sep='~')


if __name__ == '__main__':
    draw_flag()



import tempfile

from pript import pript

test_data = [{
    'name': 'No arguments ',
    'expected': '****************************************',
    'args': [],
    'kwargs': {
        'sep': '*'
    }
}, {
    'name': 'One argument ',
    'expected': 'Hello World!                            ',
    'args': ['Hello World!'],
    'kwargs': {}
}, {
    'name': 'Two arguments ',
    'expected': 'Hello                             World!',
    'args': ['Hello ', ' World!'],
    'kwargs': {}
}, {
    'name': 'Three arguments ',
    'expected': 'Hello            World            Pript!',
    'args': ['Hello ', ' World ', ' Pript!'],
    'kwargs': {}
}, {
    'name': "One arg with sep",
    'expected': 'Hello World! ...........................',
    'args': ['Hello World! '],
    'kwargs': {
        'sep': '.'
    }
}, {
    'name': "Two args with sep",
    'expected': 'Hello *************************** World!',
    'args': ['Hello ', ' World!'],
    'kwargs': {
        'sep': '*'
    }
}, {
    'name': "Three args with sep",
    'expected': 'Hello ---------- World ---------- Pript!',
    'args': ['Hello ', ' World ', ' Pript!'],
    'kwargs': {
        'sep': '-'
    }
}, {
    'name': "One arg with pos start",
    'expected': 'Hello World!                            ',
    'args': ['Hello World!'],
    'kwargs': {
        'pos': 'start'
    }
}, {
    'name': "Two args with pos start",
    'expected': 'Hello                World!             ',
    'args': ['Hello ', ' World!'],
    'kwargs': {
        'pos': 'start'
    }
}, {
    'name': "Three args with pos start",
    'expected': 'Hello  World  Pript!                    ',
    'args': ['Hello ', ' World ', ' Pript!'],
    'kwargs': {
        'pos': 'start'
    }
}, {
    'name': "One arg with pos center ",
    'expected': '              Hello World!              ',
    'args': ['Hello World!'],
    'kwargs': {
        'pos': 'center'
    }
}, {
    'name': "Two args with pos center ",
    'expected': '              Hello  World!             ',
    'args': ['Hello ', ' World!'],
    'kwargs': {
        'pos': 'center'
    }
}, {
    'name': "Three args with pos center ",
    'expected': '           Hello  World  Pript!         ',
    'args': ['Hello ', ' World ', ' Pript!'],
    'kwargs': {
        'pos': 'center'
    }
}, {
    'name': "One arg with pos end ",
    'expected': '                            Hello World!',
    'args': ['Hello World!'],
    'kwargs': {
        'pos': 'end'
    }
}, {
    'name': "Two args with pos end ",
    'expected': '              Hello               World!',
    'args': ['Hello ', ' World!'],
    'kwargs': {
        'pos': 'end'
    }
}, {
    'name': "Three args with pos end ",
    'expected': '                    Hello  World  Pript!',
    'args': ['Hello ', ' World ', ' Pript!'],
    'kwargs': {
        'pos': 'end'
    }
}, {
    'name': "One arg with length 60 ",
    'expected': 'Hello World!                                                ',
    'args': ['Hello World!'],
    'kwargs': {
        'length': 60
    }
}, {
    'name': "Two args with length 60",
    'expected': 'Hello                                                 World!',
    'args': ['Hello ', ' World!'],
    'kwargs': {
        'length': 60
    }
}, {
    'name': "Three args with length 60",
    'expected': 'Hello                      World                      Pript!',
    'args': ['Hello ', ' World ', ' Pript!'],
    'kwargs': {
        'length': 60
    }
}, {
    'name': 'One arg with snip ',
    'expected': 'Helloooooooooooooooo Woooooooooooooooorl',
    'args': ['Helloooooooooooooooo Woooooooooooooooorld!'],
    'kwargs': {
        'snip': True
    }
}, {
    'name': 'One arg with int ',
    'expected': '101                                     ',
    'args': [101],
    'kwargs': {}
}, {
    'name': 'Two args with int and str ',
    'expected': '101                         Hello World!',
    'args': [101, 'Hello World!'],
    'kwargs': {}
}, {
    'name': 'Three args with list and str ',
    'expected': "[101]       ['Pript']       Hello World!",
    'args': [[101], ['Pript'], 'Hello World!'],
    'kwargs': {}
}, {
    'name': 'More than three args ',
    'expected': "[101] ['Pript'] Hello World! ('Hello', 'World', '!')",
    'args': [[101], ['Pript'], 'Hello World!', ('Hello', 'World', '!')],
    'kwargs': {}
}]


def draw_unit(test_data):
    pript(' Starting tests ', sep='-', pos='center', length=60)
    passing = 0
    failing = 0
    with tempfile.NamedTemporaryFile('w+') as temp:
        for i, t in enumerate(test_data):
            pript(*t['args'], **t['kwargs'], file=temp, end="")
            temp.seek(0)
            contents = temp.read()
            try:
                assert contents == t['expected']
                passing += 1
                pript(t['name'], ' Passing ✓', sep='.', length=60)
            except AssertionError as error:
                failing += 1
                pript(t['name'], ' Failing X', sep='.', length=60)
            temp.seek(0)
            temp.truncate(0)
        temp.close()
    pript(' Tests completed ', sep='-', pos='center', length=60)
    pript('Passing: ', ' ' + str(passing) + ' Tests', sep='.', length=60)
    pript('Failing: ', ' ' + str(failing) + ' Tests', sep='.', length=60)


if __name__ == '__main__':
    draw_unit(test_data)



from pript import pript

from test_unit import draw_unit, test_data
from test_flag import draw_flag
from test_receipt import draw_receipt


def draw_cli():
    state = 0
    while True:
        # In state 0 the program draws the menu
        if state == 0:
            pript(sep='=')
            pript(' PRIPT CLI TEST MENU ', sep='-', pos='center')
            pript(sep='=')
            pript('Command', '/', ' Description')
            pript(sep='=')
            pript('unit ', ' Run unit tests', sep='.')
            pript('flag ', ' Draw a flag', sep='.')
            pript('receipt ', ' Print a receipt', sep='.')
            pript('exit ', ' Exit the program', sep='.')
            pript(sep='=')
            pript()
            state = 1
        if state == 1 or state == 2:
            command = input('Prompt: ')
            # In state 1 the program expects a valid input
            if state == 1:
                if command == 'unit':
                    draw_unit(test_data)
                    state = 4
                elif command == 'flag':
                    draw_flag()
                    state = 4
                elif command == 'receipt':
                    draw_receipt()
                    state = 4
                # Using 'start' in the main menu is not valid
                elif command == 'start':
                    state = 3
                elif command == 'exit':
                    state = 4
                else:
                    state = 3
            # In state 2 the program comes from an error
            elif state == 2:
                if command == 'start':
                    state = 0
                elif command == 'exit':
                    state = 4
                else:
                    state = 3
        # In state 3 the program has encountered an error
        if state == 3:
            pript(sep='=')
            pript('| ERROR ',   ' INVALID COMMAND |', sep=' ')
            pript('| ', ' |', sep='-')
            pript('| Type "start" to go', 'back to the menu  |')
            pript('| Type "exit" to lea', 've the tests       |')
            pript(sep='=')
            pript()
            state = 2
        # In state 4 exit the program
        if state == 4:
            break


if __name__ == '__main__':
    draw_cli()



import sys


def pript(*args, sep=' ', end='\n', file=None, flush=False,
          pos=None, length=40, snip=True):
    r"""pript(value, ..., sep=' ', end='\n', file=sys.stdout, 
    flush=False, pos='start', length=40, snip=False)
    
    Prints the values to a stream, or to sys.stdout by default.
    The first three arguments can be formatted in the style of a receipt.
    Optional keyword arguments:
    file:   a file-like object (stream); defaults to the current sys.stdout.
    sep:    string inserted between values, default a space.
    end:    string appended after the last value, default a newline.
    flush:  whether to forcibly flush the stream.
    pos:    alignment of the output. defaults to start and between.
    length: maximum length of the output. defaults to 40 characters.
    snip:   remove excess characters when using a single argument.
    """
    fp = file
    if fp is None:
        fp = sys.stdout
        if fp is None:
            return
    if sep is None:
        sep = ' '
    if not isinstance(sep, str):
        raise TypeError("sep must be None or a string")
    if end is None:
        end = '\n'
    if not isinstance(end, str):
        raise TypeError("end must be None or a string")
    if pos is None:
        pos = 'default'
    if not isinstance(pos, str):
        raise TypeError("pos must be None or a string")
    if length is None:
        length = 40
    if not isinstance(length, int):
        raise TypeError("length must be None or an integer")
    if snip is None:
        snip = True
    if not isinstance(snip, bool):
        raise TypeError("snip must be None or an boolean")
    if pos == 'start':
        align = [['<'], ["<", "<"], ["<", "<", "<"]]
    elif pos == 'center':
        align = [['^'], [">", "<"], [">", "^", "<"]]
    elif pos == 'end':
        align = [['>'], [">", ">"], [">", ">", ">"]]
    else:
        align = [['<'], ["<", ">"], ["<", "^", ">"]]
    if len(args) == 0:
        if sep != ' ':
            fp.write(str(sep[0]) * length)
    elif len(args) == 1:
        arg = str(args[0])
        if snip is True:
            out_single = arg[0:length]
        else:
            out_single = arg
        out = '{:{}{}{}}'
        fp.write(out.format(out_single, sep, align[0][0], length))
    elif len(args) == 2:
        compensate = length % 2
        half_len = length // 2
        arg_left = str(args[0])
        arg_right = str(args[1])
        total_len = len(arg_left) + len(arg_right)
        if total_len <= length or total_len >= length:
            out_right = arg_left[0:half_len]
            out_left = arg_right[0:half_len]
            pad_right = pad_left = half_len
        else:
            out_right = arg_left
            out_left = arg_right
            pad_right, pad_left = len(out_right), len(out_left)
        if compensate == 1:
            pad_left += compensate
        out = '{:{}{}{}}{:{}{}{}}'
        fp.write(out.format(out_right, sep,
                 align[1][0], pad_right, out_left, sep, align[1][1], pad_left))
    elif len(args) == 3:
        compensate = length % 3
        third_len = length // 3
        arg_left = str(args[0])
        arg_center = str(args[1])
        arg_right = str(args[2])
        total_len = len(arg_left) + len(arg_center) + len(arg_right)
        if total_len <= length or total_len >= length:
            out_left = arg_left[0:third_len]
            out_center = arg_center[0:third_len]
            out_right = arg_right[0:third_len]
            pad_left = pad_center = pad_right = third_len
        else:
            out_left, out_center, out_right = arg_left, arg_center, arg_right
            pad_left = len(out_left)
            pad_center = len(out_center)
            pad_right = len(out_right)
        if pos == 'center':
            pad_center = len(out_center)
            missing = length - (pad_left + pad_center + pad_right)
            if missing > 0:
                half_missing = missing // 2
                if missing % 2 == 0:
                    pad_left += half_missing
                else:
                    pad_left += half_missing + 1
                pad_right += half_missing
            out_center = out_center[0:pad_center]
        elif pos == 'start':
            pad_center = (pad_center-len(out_center))
            pad_left = (pad_left-len(out_left))
            pad_right += pad_center + pad_left + compensate
            pad_center = pad_left = 0
        elif pos == 'end':
            pad_center = (pad_center-len(out_center))
            pad_right = (pad_right-len(out_right))
            pad_left += pad_center + pad_right + compensate
            pad_center = pad_right = 0
        else:
            pad_left = (pad_left-len(out_left))
            pad_right = (pad_right-len(out_right))
            pad_center += pad_left + pad_right + compensate
            pad_left = pad_right = 0
        out = '{:{}{}{}}{:{}{}{}}{:{}{}{}}'
        fp.write(out.format(out_left, sep, align[2][0], pad_left, out_center,
                 sep, align[2][1], pad_center, out_right, sep, align[2][2], pad_right))
    else:
        for i, arg in enumerate(args):
            if i:
                fp.write(sep)
            fp.write(str(arg))
    fp.write(end)
    if flush:
        fp.flush()
